@@ -115,6 +115,9 @@ class CONTENT_TYPE(object):
         'application/vnd.openxmlformats-officedocument.presentationml.presen'
         'tation.main+xml'
     )
+    PML_PRES_MACRO_MAIN = (
+        'application/vnd.ms-powerpoint.presentation.macroEnabled.main+xml'
+    )
     PML_PRES_PROPS = (
         'application/vnd.openxmlformats-officedocument.presentationml.presPr'
         'ops+xml'
